==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/diamond_support/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>DiamondBuildValidator</name>
    <message>
        <source>Taxonomy classification data from NCBI are not available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Taxonomy classification data from NCBI are not full: file &apos;%1&apos; is missing.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>DIAMOND external tool support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The plugin supports DIAMOND: a sequence aligner for protein and translated DNA searches, designed for high performance analysis of big sequence data (https://github.com/bbuchfink/diamond)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DiamondBuildTask</name>
    <message>
        <source>Build DIAMOND database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no input files to build the database from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Taxon map URL is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Taxon nodes URL is empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DiamondClassifyTask</name>
    <message>
        <source>Classify sequences with DIAMOND</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reads URL is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DIAMOND database URL is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DIAMOND classification URL is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid genetic code: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown sensitivity value: %1, ignored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open classification report: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate sequence name &apos;%1&apos; have been detected in the classification output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Broken Diamond report : %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DiamondSupport</name>
    <message>
        <source>In general, DIAMOND is a sequence aligner for protein and translated DNA searches similar to the NCBI BLAST software tools. In UGENE it is integrated as one of the taxonomic classification tool.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::GenomesPreparationTask</name>
    <message>
        <source>Genomes preparation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genomes URLs are not set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File URL to write prepared genomes is empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondBuildPrompter</name>
    <message>
        <source>Use custom data to build %1 DIAMOND database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output URL.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output DIAMOND database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL to the DIAMOND database file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A name of the binary DIAMOND database file that should be created.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genomic library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genomes that should be used to build the database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Build DIAMOND Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Build a DIAMOND formatted database from a FASTA input file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondBuildWorker</name>
    <message>
        <source>Taxonomy classification data from NCBI are not available.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondClassifyPrompter</name>
    <message>
        <source>Classify sequences from &lt;u&gt;%1&lt;/u&gt; with DIAMOND, use %2 database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input URL.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL(s) to FASTQ or FASTA file(s) should be provided.

The input files may contain single-end reads, contigs, or &quot;left&quot; reads in case of the paired-end sequencing (see &quot;Input data&quot; parameter of the element).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DIAMOND Classification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A list of sequence names with the associated taxonomy IDs, classified by DIAMOND.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input a binary DIAMOND database file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genetic code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genetic code used for translation of query sequences (--query-gencode).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sensitive mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The sensitive modes (--sensitive, --more-sensitive) are generally recommended for aligning longer sequences. The default mode is mainly designed for short read alignment, i.e. finding significant matches of &gt;50 bits on 30-40aa fragments.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frameshift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Penalty for frameshift in DNA-vs-protein alignments. Values around 15 are reasonable for this parameter. Enabling this feature will have the aligner tolerate missing bases in DNA sequences and is most recommended for long, error-prone sequences like MinION reads.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matrix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scoring matrix (--matrix).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gap open penalty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gap open penalty (--gapopen).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gap extension penalty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gap extension penalty (--gapextend).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of CPU threads (--treads).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index chunks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The number of chunks for processing the seed index (--index-chunks). This option can be additionally used to tune the performance. It is recommended to set this to 1 on a high memory server, which will increase performance and memory usage, but not the usage of temporary disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classify Sequences with DIAMOND</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top alignments percentage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DIAMOND uses the lowest common ancestor (LCA) algorithm for taxonomy classification of the input sequences. This parameter specifies what alignments should be taken into account during the calculations (--top).&lt;br&gt;&lt;br&gt;For example, the default value &quot;10&quot; means to take top 10% of the best hits (i.e. sort all query/subject-alignments by score, take top 10% of the alignments with the best score, calculate the lowest common ancestor for them).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum expected value to report an alignment (--evalue/-e).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specify the output file name.&lt;br&gt;&lt;br&gt;The output file is a tab-delimited file with the following fields:&lt;ul&gt;&lt;li&gt;Query ID&lt;/li&gt;&lt;li&gt;NCBI taxonomy ID (0 if unclassified)&lt;/li&gt;&lt;li&gt;E-value of the best alignment with a known taxonomy ID found for the query (0 if unclassified)&lt;/li&gt;&lt;/ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In general, DIAMOND is a sequence aligner for protein and translated DNA searches similar to the NCBI BLAST software tools. However, it provides a speedup of BLAST ranging up to x20,000.&lt;br&gt;&lt;br&gt;Using this workflow element one can use DIAMOND for taxonomic classification of short DNA reads and longer sequences such as contigs. The lowest common ancestor (LCA) algorithm is used for the classification.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block size in billions of sequence letters to be processed at a time (--block-size). This is the main parameter for controlling the program’s memory usage. Bigger numbers will increase the use of memory and temporary disk space, but also improve performance. The program can be expected to use roughly six times this number of memory (in GB).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondClassifyWorker</name>
    <message>
        <source>There were %1 input reads, %2 reads were classified.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/diamond_support/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>DiamondBuildValidator</name>
    <message>
        <source>Taxonomy classification data from NCBI are not available.</source>
        <translation></translation>
    </message>
    <message>
        <source>Taxonomy classification data from NCBI are not full: file &apos;%1&apos; is missing.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>DIAMOND external tool support</source>
        <translation></translation>
    </message>
    <message>
        <source>The plugin supports DIAMOND: a sequence aligner for protein and translated DNA searches, designed for high performance analysis of big sequence data (https://github.com/bbuchfink/diamond)</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DiamondBuildTask</name>
    <message>
        <source>Build DIAMOND database</source>
        <translation></translation>
    </message>
    <message>
        <source>There is no input files to build the database from</source>
        <translation></translation>
    </message>
    <message>
        <source>Taxon map URL is empty</source>
        <translation></translation>
    </message>
    <message>
        <source>Taxon nodes URL is empty</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DiamondClassifyTask</name>
    <message>
        <source>Classify sequences with DIAMOND</source>
        <translation></translation>
    </message>
    <message>
        <source>Reads URL is empty</source>
        <translation></translation>
    </message>
    <message>
        <source>DIAMOND database URL is empty</source>
        <translation></translation>
    </message>
    <message>
        <source>DIAMOND classification URL is empty</source>
        <translation></translation>
    </message>
    <message>
        <source>Invalid genetic code: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown sensitivity value: %1, ignored.</source>
        <translation></translation>
    </message>
    <message>
        <source>Cannot open classification report: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Duplicate sequence name &apos;%1&apos; have been detected in the classification output.</source>
        <translation></translation>
    </message>
    <message>
        <source>Broken Diamond report : %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DiamondSupport</name>
    <message>
        <source>DIAMOND is a sequence aligner for protein and translated DNA searches similar to the NCBI BLAST software tools. In UGENE it is integrated as one of the taxonomic classification tool.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::GenomesPreparationTask</name>
    <message>
        <source>Genomes preparation</source>
        <translation></translation>
    </message>
    <message>
        <source>Genomes URLs are not set</source>
        <translation></translation>
    </message>
    <message>
        <source>File URL to write prepared genomes is empty</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondBuildPrompter</name>
    <message>
        <source>Use custom data to build %1 DIAMOND database.</source>
        <translation></translation>
    </message>
    <message>
        <source>Output URL</source>
        <translation></translation>
    </message>
    <message>
        <source>Output URL.</source>
        <translation></translation>
    </message>
    <message>
        <source>Output DIAMOND database</source>
        <translation></translation>
    </message>
    <message>
        <source>URL to the DIAMOND database file.</source>
        <translation></translation>
    </message>
    <message>
        <source>Database</source>
        <translation></translation>
    </message>
    <message>
        <source>A name of the binary DIAMOND database file that should be created.</source>
        <translation></translation>
    </message>
    <message>
        <source>Genomic library</source>
        <translation></translation>
    </message>
    <message>
        <source>Genomes that should be used to build the database.</source>
        <translation></translation>
    </message>
    <message>
        <source>Build DIAMOND Database</source>
        <translation></translation>
    </message>
    <message>
        <source>Build a DIAMOND formatted database from a FASTA input file.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondBuildWorker</name>
    <message>
        <source>Taxonomy classification data from NCBI are not available.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondClassifyPrompter</name>
    <message>
        <source>Classify sequences from &lt;u&gt;%1&lt;/u&gt; with DIAMOND, use %2 database.</source>
        <translation></translation>
    </message>
    <message>
        <source>Input URL</source>
        <translation></translation>
    </message>
    <message>
        <source>Input URL.</source>
        <translation></translation>
    </message>
    <message>
        <source>Input sequences</source>
        <translation></translation>
    </message>
    <message>
        <source>URL(s) to FASTQ or FASTA file(s) should be provided.

The input files may contain single-end reads, contigs, or &quot;left&quot; reads in case of the paired-end sequencing (see &quot;Input data&quot; parameter of the element).</source>
        <translation></translation>
    </message>
    <message>
        <source>DIAMOND Classification</source>
        <translation></translation>
    </message>
    <message>
        <source>A list of sequence names with the associated taxonomy IDs, classified by DIAMOND.</source>
        <translation></translation>
    </message>
    <message>
        <source>Database</source>
        <translation></translation>
    </message>
    <message>
        <source>Input a binary DIAMOND database file.</source>
        <translation></translation>
    </message>
    <message>
        <source>Genetic code</source>
        <translation></translation>
    </message>
    <message>
        <source>Genetic code used for translation of query sequences (--query-gencode).</source>
        <translation></translation>
    </message>
    <message>
        <source>Sensitive mode</source>
        <translation></translation>
    </message>
    <message>
        <source>The sensitive modes (--sensitive, --more-sensitive) are generally recommended for aligning longer sequences. The default mode is mainly designed for short read alignment, i.e. finding significant matches of &gt;50 bits on 30-40aa fragments.</source>
        <translation></translation>
    </message>
    <message>
        <source>Frameshift</source>
        <translation></translation>
    </message>
    <message>
        <source>Penalty for frameshift in DNA-vs-protein alignments. Values around 15 are reasonable for this parameter. Enabling this feature will have the aligner tolerate missing bases in DNA sequences and is most recommended for long, error-prone sequences like MinION reads.</source>
        <translation></translation>
    </message>
    <message>
        <source>Expected value</source>
        <translation></translation>
    </message>
    <message>
        <source>Matrix</source>
        <translation></translation>
    </message>
    <message>
        <source>Scoring matrix (--matrix).</source>
        <translation></translation>
    </message>
    <message>
        <source>Gap open penalty</source>
        <translation></translation>
    </message>
    <message>
        <source>Gap open penalty (--gapopen).</source>
        <translation></translation>
    </message>
    <message>
        <source>Gap extension penalty</source>
        <translation></translation>
    </message>
    <message>
        <source>Gap extension penalty (--gapextend).</source>
        <translation></translation>
    </message>
    <message>
        <source>Number of threads</source>
        <translation></translation>
    </message>
    <message>
        <source>Number of CPU threads (--treads).</source>
        <translation></translation>
    </message>
    <message>
        <source>Block size</source>
        <translation></translation>
    </message>
    <message>
        <source>Index chunks</source>
        <translation></translation>
    </message>
    <message>
        <source>The number of chunks for processing the seed index (--index-chunks). This option can be additionally used to tune the performance. It is recommended to set this to 1 on a high memory server, which will increase performance and memory usage, but not the usage of temporary disk space.</source>
        <translation></translation>
    </message>
    <message>
        <source>Output file</source>
        <translation></translation>
    </message>
    <message>
        <source>Default</source>
        <translation></translation>
    </message>
    <message>
        <source>Sensitive</source>
        <translation></translation>
    </message>
    <message>
        <source>More sensitive</source>
        <translation></translation>
    </message>
    <message>
        <source>Skipped</source>
        <translation></translation>
    </message>
    <message>
        <source>Classify Sequences with DIAMOND</source>
        <translation></translation>
    </message>
    <message>
        <source>Top alignments percentage</source>
        <translation></translation>
    </message>
    <message>
        <source>DIAMOND uses the lowest common ancestor (LCA) algorithm for taxonomy classification of the input sequences. This parameter specifies what alignments should be taken into account during the calculations (--top).&lt;br&gt;&lt;br&gt;For example, the default value &quot;10&quot; means to take top 10% of the best hits (i.e. sort all query/subject-alignments by score, take top 10% of the alignments with the best score, calculate the lowest common ancestor for them).</source>
        <translation></translation>
    </message>
    <message>
        <source>Maximum expected value to report an alignment (--evalue/-e).</source>
        <translation></translation>
    </message>
    <message>
        <source>Specify the output file name.&lt;br&gt;&lt;br&gt;The output file is a tab-delimited file with the following fields:&lt;ul&gt;&lt;li&gt;Query ID&lt;/li&gt;&lt;li&gt;NCBI taxonomy ID (0 if unclassified)&lt;/li&gt;&lt;li&gt;E-value of the best alignment with a known taxonomy ID found for the query (0 if unclassified)&lt;/li&gt;&lt;/ul&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>In general, DIAMOND is a sequence aligner for protein and translated DNA searches similar to the NCBI BLAST software tools. However, it provides a speedup of BLAST ranging up to x20,000.&lt;br&gt;&lt;br&gt;Using this workflow element one can use DIAMOND for taxonomic classification of short DNA reads and longer sequences such as contigs. The lowest common ancestor (LCA) algorithm is used for the classification.</source>
        <translation></translation>
    </message>
    <message>
        <source>Block size in billions of sequence letters to be processed at a time (--block-size). This is the main parameter for controlling the program’s memory usage. Bigger numbers will increase the use of memory and temporary disk space, but also improve performance. The program can be expected to use roughly six times this number of memory (in GB).</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::DiamondClassifyWorker</name>
    <message>
        <source>There were %1 input reads, %2 reads were classified.</source>
        <translation></translation>
    </message>
</context>
</TS>
